@@ -7,9 +7,8 @@ SPDX-License-Identifier: BSD-3-Clause
 
 #include "FederateInfo.hpp"
 
-#include "../common/JsonProcessingFunctions.hpp"
-#include "../common/TomlProcessingFunctions.hpp"
 #include "../common/addTargets.hpp"
+#include "../common/configFileHelpers.hpp"
 #include "../core/core-exceptions.hpp"
 #include "../core/helicsCLI11.hpp"
 #include "../core/helicsCLI11JsonConfig.hpp"
@@ -133,7 +132,7 @@ static constexpr frozen::unordered_map<std::string_view, int, 69> propStringsTra
     {"logBuffer", HELICS_PROPERTY_INT_LOG_BUFFER},
     {"log_buffer", HELICS_PROPERTY_INT_LOG_BUFFER}};
 
-static constexpr frozen::unordered_map<std::string_view, int, 95> flagStringsTranslations{
+static constexpr frozen::unordered_map<std::string_view, int, 97> flagStringsTranslations{
     {"source_only", HELICS_FLAG_SOURCE_ONLY},
     {"sourceonly", HELICS_FLAG_SOURCE_ONLY},
     {"sourceOnly", HELICS_FLAG_SOURCE_ONLY},
@@ -233,7 +232,7 @@ static constexpr frozen::unordered_map<std::string_view, int, 95> flagStringsTra
     {"disableremotecontrol", HELICS_FLAG_DISABLE_REMOTE_CONTROL},
     {"disable_remote_control", HELICS_FLAG_DISABLE_REMOTE_CONTROL}};
 
-static constexpr frozen::unordered_map<std::string_view, int, 41> optionStringsTranslations{
+static constexpr frozen::unordered_map<std::string_view, int, 42> optionStringsTranslations{
     {"buffer_data", HELICS_HANDLE_OPTION_BUFFER_DATA},
     {"bufferdata", HELICS_HANDLE_OPTION_BUFFER_DATA},
     {"bufferData", HELICS_HANDLE_OPTION_BUFFER_DATA},
@@ -469,7 +468,12 @@ int getOptionValue(std::string val)
 void FederateInfo::injectParser(CLI::App* app)
 {
     auto lparser = makeCLIApp();
+    lparser->final_callback([app, this]() { config_additional(app); });
     app->add_subcommand(std::move(lparser));
+    // make sure the injector has json configuration handling capability
+    auto* fmtr = addJsonConfig(app);
+    fmtr->maxLayers(0);
+    fmtr->promoteSection("helics");
 }
 
 std::unique_ptr<helicsCLI11App> FederateInfo::makeCLIApp()
@@ -488,6 +492,7 @@ std::unique_ptr<helicsCLI11App> FederateInfo::makeCLIApp()
                     "specify a configuration file");
     auto* fmtr = addJsonConfig(app.get());
     fmtr->maxLayers(0);
+    fmtr->promoteSection("helics");
     app->add_option("--name,-n", defName, "name of the federate");
     auto* networking = app->add_option_group("network type")->immediate_callback();
     networking
@@ -538,6 +543,24 @@ std::unique_ptr<helicsCLI11App> FederateInfo::makeCLIApp()
     app->add_option("--brokerport", brokerPort, "Port number of the Broker")
         ->check(CLI::PositiveNumber);
 
+    auto* brokersub = app->add_subcommand("broker", "broker specific options");
+    brokersub->add_option("--host,--name", broker, "address or name of the broker to connect");
+    brokersub->add_option("--port", brokerPort, "port to connect to");
+    brokersub->add_flag("--auto",
+                        autobroker,
+                        "tell the core to automatically generate a broker if needed");
+    brokersub->add_option("--key",
+                          key,
+                          "specify a key to use to match a broker should match the broker key");
+    brokersub
+        ->add_option("--initstring",
+                     brokerInitString,
+                     "The initialization arguments for the broker if autogenerated")
+        ->transform([](std::string arg) {
+            arg.insert(arg.begin(), ' ');
+            return arg;
+        })
+        ->multi_option_policy(CLI::MultiOptionPolicy::Join);
     app->add_option_function<int>(
            "--port",
            [this](int port) {
@@ -731,18 +754,19 @@ void FederateInfo::loadInfoFromArgs(std::vector<std::string>& args)
     config_additional(app.get());
 }
 
-void FederateInfo::config_additional(helicsCLI11App* app)
+void FederateInfo::config_additional(CLI::App* app)
 {
     auto* opt = app->get_option("--config");
     if (opt->count() > 0) {
-        auto configString = opt->as<std::string>();
+        configString = opt->as<std::string>();
         if (CLI::ExistingFile(configString).empty()) {
             if (fileops::hasTomlExtension(configString)) {
                 loadInfoFromToml(configString, false);
-                fileInUse = configString;
+                fileInUse = true;
+
             } else if (fileops::hasJsonExtension(configString)) {
                 loadInfoFromJson(configString, false);
-                fileInUse = configString;
+                fileInUse = true;
             }
         }
     }
@@ -751,21 +775,60 @@ void FederateInfo::config_additional(helicsCLI11App* app)
 FederateInfo loadFederateInfo(const std::string& configString)
 {
     FederateInfo ret;
-    if (fileops::looksLikeCommandLine(configString)) {
-        ret.loadInfoFromArgsIgnoreOutput(configString);
-    } else if (fileops::hasTomlExtension(configString)) {
-        ret.loadInfoFromToml(configString);
-        ret.fileInUse = configString;
-    } else if (fileops::hasJsonExtension(configString)) {
-        ret.loadInfoFromJson(configString);
-        ret.fileInUse = configString;
-    } else if (configString.find_first_of('{') != std::string::npos) {
-        ret.loadInfoFromJson(configString);
-    } else if (configString.find('=') != std::string::npos) {
-        ret.loadInfoFromToml(configString);
-    } else {
-        ret.defName = configString;
+    auto type = fileops::getConfigType(configString);
+    switch (type) {
+        case fileops::ConfigType::JSON_FILE:
+            ret.fileInUse = true;
+            ret.loadInfoFromJson(configString);
+            ret.configString = configString;
+            break;
+        case fileops::ConfigType::JSON_STRING:
+            try {
+                ret.loadInfoFromJson(configString);
+                ret.configString = configString;
+            }
+            catch (const helics::InvalidParameter&) {
+                if (fileops::looksLikeConfigToml(configString)) {
+                    try {
+                        ret.loadInfoFromToml(configString);
+                        ret.configString = configString;
+                    }
+                    catch (const helics::InvalidParameter&) {
+                        if (fileops::looksLikeCommandLine(configString)) {
+                            ret.loadInfoFromArgsIgnoreOutput(configString);
+                            break;
+                        }
+                        throw;
+                    }
+                }
+                throw;
+            }
+            break;
+        case fileops::ConfigType::TOML_FILE:
+            ret.fileInUse = true;
+            ret.loadInfoFromToml(configString);
+            ret.configString = configString;
+            break;
+        case fileops::ConfigType::TOML_STRING:
+            try {
+                ret.loadInfoFromToml(configString);
+                ret.configString = configString;
+            }
+            catch (const helics::InvalidParameter&) {
+                if (fileops::looksLikeCommandLine(configString)) {
+                    ret.loadInfoFromArgsIgnoreOutput(configString);
+                    break;
+                }
+                throw;
+            }
+            break;
+        case fileops::ConfigType::CMD_LINE:
+            ret.loadInfoFromArgsIgnoreOutput(configString);
+            break;
+        case fileops::ConfigType::NONE:
+            ret.defName = configString;
     }
+
     return ret;
 }
 
@@ -809,7 +872,7 @@ void FederateInfo::loadInfoFromJson(const std::string& jsonString, bool runArgPa
         throw(helics::InvalidParameter(iarg.what()));
     }
     loadJsonConfig(doc);
-    bool hasHelicsSection = doc.isMember("helics");
+    const bool hasHelicsSection = doc.isMember("helics");
     bool hasHelicsSubSection{false};
     if (hasHelicsSection) {
         hasHelicsSubSection = doc["helics"].isMember("helics");
@@ -874,6 +937,16 @@ void FederateInfo::loadJsonConfig(Json::Value& json)
         [](const std::string& value) { return getOptionValue(value); },
         [this](int32_t option, int32_t value) { setFlagOption(option, value != 0); });
 
+    if (json.isMember("broker")) {
+        const auto& jbroker = json["broker"];
+        fileops::replaceIfMember(jbroker, "name", broker);
+        fileops::replaceIfMember(jbroker, "host", broker);
+        fileops::replaceIfMember(jbroker, "initstring", brokerInitString);
+        fileops::replaceIfMember(jbroker, "key", key);
+        fileops::replaceIfMember(jbroker, "auto", autobroker);
+        fileops::replaceIfMember(jbroker, "port", brokerPort);
+    }
+
     if (json.isMember("helics")) {
         loadJsonConfig(json["helics"]);
     }
@@ -978,9 +1051,9 @@ std::string generateFullCoreInitString(const FederateInfo& fedInfo)
         res += " --broker_key=";
         res.append(fedInfo.key);
     }
-    if (!fedInfo.fileInUse.empty()) {  // we used the file, specify a core section
+    if (fedInfo.fileInUse) {  // we used the file, specify a core section
         res += " --config_section=core --config-file='";
-        res.append(fedInfo.fileInUse);
+        res.append(fedInfo.configString);
         res.push_back('\'');
     }
     return res;
