@@ -17,6 +17,15 @@ SPDX-License-Identifier: BSD-3-Clause
 #include <vector>
 
 namespace helics {
+
+void InterfaceInfo::reset()
+{
+    publications.lock()->clear();
+    inputs.lock()->clear();
+    endpoints.lock()->clear();
+    only_update_on_change = false;
+}
+
 void InterfaceInfo::createPublication(InterfaceHandle handle,
                                       std::string_view key,
                                       std::string_view type,
@@ -437,7 +446,6 @@ void InterfaceInfo::generateDataFlowGraph(Json::Value& base) const
 {
     auto ihandle = inputs.lock_shared();
     if (ihandle->size() > 0) {
-        base["inputs"] = Json::arrayValue;
         for (const auto& ipt : ihandle) {
             Json::Value ibase;
             if (!ipt->key.empty()) {
@@ -473,10 +481,10 @@ void InterfaceInfo::generateDataFlowGraph(Json::Value& base) const
                 pbase["targets"] = Json::arrayValue;
                 for (auto& target : pub->subscribers) {
                     Json::Value sid;
-                    sid["federate"] = target.first.fed_id.baseValue();
-                    sid["handle"] = target.first.handle.baseValue();
-                    if (!target.second.empty()) {
-                        sid["key"] = target.second;
+                    sid["federate"] = target.id.fed_id.baseValue();
+                    sid["handle"] = target.id.handle.baseValue();
+                    if (!target.key.empty()) {
+                        sid["key"] = target.key;
                     }
                     pbase["targets"].append(sid);
                 }
@@ -502,4 +510,29 @@ void InterfaceInfo::generateDataFlowGraph(Json::Value& base) const
     ehandle.unlock();
 }
 
+void InterfaceInfo::disconnectFederate(GlobalFederateId fedToDisconnect, Time disconnectTime)
+{
+    if (disconnectTime < cBigTime) {
+        auto ihandle = inputs.lock_shared();
+        for (auto& ipt : ihandle) {
+            ipt->disconnectFederate(fedToDisconnect, disconnectTime);
+        }
+        ihandle.unlock();
+    }
+
+    auto phandle = publications.lock();
+
+    for (auto& pub : phandle) {
+        pub->disconnectFederate(fedToDisconnect);
+    }
+    phandle.unlock();
+
+    auto ehandle = endpoints.lock_shared();
+
+    for (auto& ept : ehandle) {
+        ept->disconnectFederate(fedToDisconnect);
+    }
+    ehandle.unlock();
+}
+
 }  // namespace helics
